==> playvideo-1.2.zip: playvideo-1.2/plugin/playvideo.inc.pl <==
############################################################
# playvideo plugin
# playvideo.inc.pl
# Copyright(c) 2010 Nanami.
# for PyukiWiki 0.1.7 (http://nanakochi.daiba.cx/)
#
# 2010/11/13 change: ̵zipǥɤǤ褦ˤ
#                    ̤ư褬Ȥå夫褦
#                    ͭ¤ϣ֤Ǥ
# 2010/10/27 change: MSIE OperaʳWindwos Mediaץ쥤䡼
#                    _blank(¼̥֡ˤˤʤ褦ˤ
#                    SafariǤˤʤޤ
# 2010/10/24 change: use sub make_link_target
#
# 1TAB=4Spaces

use Nana::Cache;
use Image::ExifTool;
require "plugin/counter.inc.pl";

$playvideo_plugin_usedownload=1;	# Ȥʤ0ˤ롣
$playvideo_plugin_zipcmds=<<EOM;
/usr/bin/zip
/usr/local/bin/zip
EOM
$playvideo_plugin_zipflags="-0";
$playvideo_plugin_ziptmp="/tmp";
$playvideo_plugin_videopath="video";

sub plugin_playvideo_inline {
	my ($arg)=@_;
	my ($fname,$youtube)=split(/,/,$arg);
	my $body;

	$playsite="http://$ENV{HTTP_HOST}/v.cgi";
	$videopath=$playvideo_plugin_videopath;
	$videourl="http://$ENV{HTTP_HOST}/$videopath";
	$fname=~s/\..*//g;
	$ext="asx";
	$wmv="wmv";
	$zip="zip";

	my $browser=$ENV{'HTTP_USER_AGENT'};

	my $wmvtarget = "";
	if ($browser=~/MSIE/ || $browser=~/Opera/ ) { 
	} else {
		$wmvtarget = "_blank";
	}
	$body.=<<EOM;
<strong>
@{[&make_link_target("$playsite/$fname.$ext","",$wmvtarget,"Windows Media PlayerǺ")]}
[Windows Media PlayerǺ]</a></strong>
EOM
	if($youtube ne '') {
		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$youtube","","_blank","YoutubeǺ")]}
[YoutubeǺ]</a>
EOM
	}
	if($playvideo_plugin_usedownload eq 1) {

		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$zip","","","")]}
[]</a>
EOM
	}

	my $cache=new Nana::Cache (
		ext=>"playvideo",
		files=>500,
		dir=>$::cache_dir,
		size=>100000,
		use=>1,
		expire=>3600
	);
	my $cachefile="playvideo_time_$fname";
	my $buf=$cache->read($cachefile,1);
	if($buf eq '') {
		my $exifTool = new Image::ExifTool;
		my $info = $exifTool->ImageInfo("$videopath/$fname.$wmv");
		$buf=$$info{SendDuration};
		$cache->write($cachefile,$buf);
	}
	$body.=<<EOM;
($buf)
<br>
EOM
	%vcounter=&plugin_counter_do("playvideo_$fname","r");
	$body.=<<EOM;
<span style="font-size: 10px;">
TOTAL: $vcounter{total} TODAY: $vcounter{today} YESTERDAY:$vcounter{yesterday}
</span>
EOM

	return $body;
}
1;

==> playvideo-1.3.zip: playvideo-1.3/plugin/playvideo.inc.pl <==
############################################################
# playvideo plugin
# playvideo.inc.pl
# Copyright(c) 2010 Nanami.
# for PyukiWiki 0.1.7 (http://nanakochi.daiba.cx/)
#
# 2010/12/10 change: ˥˥ưб
#                    ĥҤwmxѹ
# 2010/11/13 change: ̵zipǥɤǤ褦ˤ
#                    ̤ư褬Ȥå夫褦
#                    ͭ¤ϣ֤Ǥ
# 2010/10/27 change: MSIE OperaʳWindwos Mediaץ쥤䡼
#                    _blank(¼̥֡ˤˤʤ褦ˤ
#                    SafariǤˤʤޤ
# 2010/10/24 change: use sub make_link_target
#
# 1TAB=4Spaces

use Nana::Cache;
use Image::ExifTool;
require "plugin/counter.inc.pl";

$playvideo_plugin_usedownload=1;	# Ȥʤ0ˤ롣
$playvideo_plugin_zipcmds=<<EOM;
/usr/bin/zip
/usr/local/bin/zip
EOM
$playvideo_plugin_zipflags="-0";
$playvideo_plugin_ziptmp="/tmp";
$playvideo_plugin_videopath="video";
$playvideo_plugin_playsite="http://$ENV{HTTP_HOST}/v.cgi";
$playvideo_plugin_videourl="http://$ENV{HTTP_HOST}/$videopath";

sub plugin_playvideo_inline {
	my ($arg)=@_;
	my ($fname,$youtube,$nicovideo)=split(/,/,$arg);
	my $body;

	$videopath=$playvideo_plugin_videopath;
	$playsite=$playvideo_plugin_playsite;
	$videourl=$playvideo_plugin_videourl;
	$fname=~s/\..*//g;
#	$ext="asx";
	$ext="wmx";
	$wmv="wmv";
	$zip="zip";

	my $browser=$ENV{'HTTP_USER_AGENT'};

	my $wmvtarget = "";
	if ($browser=~/MSIE/ || $browser=~/Opera/ ) { 
	} else {
		$wmvtarget = "_blank";
	}
	$body.=<<EOM;
<strong>
@{[&make_link_target("$playsite/$fname.$ext","",$wmvtarget,"Windows Media PlayerǺ")]}
[Windows Media PlayerǺ]</a></strong>
EOM
	if($youtube ne '') {
		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$youtube","","_blank","YoutubeǺ")]}
[YoutubeǺ]</a>
EOM
	}

	if($nicovideo ne '') {
		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$nicovideo","","_blank","˥˥ưǺ")]}
[˥˥ưǺ]</a>
EOM
	}
	if($playvideo_plugin_usedownload eq 1) {

		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$zip","","","")]}
[]</a>
EOM
	}

	my $cache=new Nana::Cache (
		ext=>"playvideo",
		files=>500,
		dir=>$::cache_dir,
		size=>100000,
		use=>1,
		expire=>3600
	);
	my $cachefile="playvideo_time_$fname";
	my $buf=$cache->read($cachefile,1);
	if($buf eq '') {
		my $exifTool = new Image::ExifTool;
		my $info = $exifTool->ImageInfo("$videopath/$fname.$wmv");
		$buf=$$info{SendDuration};
		$cache->write($cachefile,$buf);
	}
	$body.=<<EOM;
($buf)
<br>
EOM
	%vcounter=&plugin_counter_do("playvideo_$fname","r");
	$body.=<<EOM;
<span style="font-size: 10px;">
TOTAL: $vcounter{total} TODAY: $vcounter{today} YESTERDAY:$vcounter{yesterday}
</span>
EOM

	return $body;
}
1;
